Conversion factors from oxides to elements
conversion_oxides.RdConversion factors from oxides to elements
Format
A data frame with 106 rows and 7 variables:
- Element
The symbol of a chemical element.
- AtomicWeight
The atomic weight (= molar mass) of the respective element.
- Oxide
The formula of the chemical element's oxide.
- M
The number of oxygen atoms in the oxide = the number of moles oxygen per mole oxide.
- OxideWeight
The molar mass of the oxide.
- ElementToOxide
The factor used in the conversion from the chemical element to its oxide.
- OxideToElement
The factor used in the conversion from the oxide to its chemical element.
- OxidationState
The oxidation state of the kation as numeric value.
See also
Other chemical_reference_data:
elements_data,
isotopes_data,
oxides_data,
special_oxide_states